<?php

defined('ABSPATH') || exit();

// enable auto update
add_filter('allow_major_auto_core_updates', '__return_true');
add_filter('allow_minor_auto_core_updates', '__return_true');
add_filter('auto_update_theme', '__return_true');
add_filter('auto_update_plugin', '__return_true');

// remove parent theme defined filters and actions
add_action('after_setup_theme', 'cbsonline_disable_parent_defines');
function cbsonline_disable_parent_defines()
{
    // remove web fonts
    remove_action('wp_enqueue_scripts', 'biz_vektor_addWebFonts');
    // remove buggy biz_vector script
    remove_action('wp_head', 'biz_vektor_addJScripts');
    // remove pingback css
    remove_action('wp_enqueue_scripts','biz_vektor_addPingback');
}

// disable emoji
remove_action('wp_head', 'print_emoji_detection_script', 7);
remove_action('admin_print_scripts', 'print_emoji_detection_script');
remove_action('wp_print_styles', 'print_emoji_styles');
remove_action('admin_print_styles', 'print_emoji_styles');
remove_filter('the_content_feed', 'wp_staticize_emoji');
remove_filter('comment_text_rss', 'wp_staticize_emoji');
remove_filter('wp_mail', 'wp_staticize_emoji_for_email');
// add_filter('tiny_mce_plugins', 'disable_emojis_tinymce');

// remove unnecessary head tags
// - rest
remove_action('wp_head', 'rest_output_link_wp_head');
// - embed
remove_action('wp_head', 'wp_oembed_add_discovery_links');
remove_action('wp_head', 'wp_oembed_add_host_js');
// - feed
remove_action('wp_head', 'feed_links', 2);
remove_action('wp_head', 'feed_links_extra', 3);
// - rsd
remove_action('wp_head', 'rsd_link');
// - windows live writer
remove_action('wp_head', 'wlwmanifest_link');
// - generator
remove_action('wp_head', 'wp_generator');
// - shortlink
remove_action('wp_head', 'wp_shortlink_wp_head');
// - rel link
remove_action('wp_head', 'index_rel_link');
remove_action('wp_head', 'parent_post_rel_link', 10);
remove_action('wp_head', 'start_post_rel_link', 10);
remove_action('wp_head', 'adjacent_posts_rel_link_wp_head');

// disable automatically appending srcset attribute in img tag
add_filter('wp_calculate_image_srcset_meta', '__return_null');

// disable DNS prefetch
add_filter('wp_resource_hints', 'cbsonline_remove_dns_prefetch', 10, 2);
function cbsonline_remove_dns_prefetch($hints, $relation_type)
{
    if ('dns-prefetch' === $relation_type) {
        return array_diff(wp_dependencies_unique_hosts(), $hints);
    }

    return $hints;
}

// add styles
add_action('wp_enqueue_scripts', 'cbsonline_add_styles');
function cbsonline_add_styles()
{
    wp_enqueue_style('parent-style', get_template_directory_uri().'/style.css');
    wp_enqueue_style('dashicons');
}

// add scripts
add_action('wp_head', 'cbsonline_add_scripts');
function cbsonline_add_scripts()
{
    wp_register_script('biz-vektor-fix-min-js', get_stylesheet_directory_uri().'/js/biz-vektor-fix-min.js', ['jquery'], '20201029');
    wp_enqueue_script('biz-vektor-fix-min-js');
}

// add widgets
function cbsonline_widgets_init()
{
    register_sidebar([
        'name' => 'ヘッダー ウィジェット',
        'id' => 'header-widget-area',
        'before_widget' => '<div class="header-widget-area">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="rounded">',
        'after_title' => '</h2>',
    ]);

    register_sidebar([
        'name' => 'トップバナー ウィジェット',
        'id' => 'topbnr-widget-area',
        'before_widget' => '<div class="topbnr-widget-area clearfix"><div class="topbnr-widget-area-inner clearfix">',
        'after_widget' => '</div></div>',
        'before_title' => '<h2 class="rounded">',
        'after_title' => '</h2>',
    ]);

    register_sidebar([
        'name' => 'トップイメージ ウィジェット',
        'id' => 'topimg-widget-area',
        'before_widget' => '<div class="topimg-widget-area clearfix">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="rounded">',
        'after_title' => '</h2>',
    ]);
}
add_action('widgets_init', 'cbsonline_widgets_init');

// tweak bogo plugin
// - disable flags
add_filter('bogo_use_flags', 'cbsonline_bogo_use_flags_false');
function cbsonline_bogo_use_flags_false()
{
    return false;
}
// - remove ' (United States)' strings from en_US language
add_filter('bogo_language_switcher', 'cbsonline_replace_bogo_text');
function cbsonline_replace_bogo_text($output)
{
    return str_replace(' (United States)', '', $output);
}

// add short code
// - topbox : http://www.webopixel.net/wordpress/53.html
function cbsonline_shortcode_TopBox($atts, $content = null)
{
    $content = do_shortcode(shortcode_unautop($content));
    extract(shortcode_atts(['class' => 'default'], $atts));

    return '<div class="topbox">'.$content.'</div>';
}
add_shortcode('topbox', 'cbsonline_shortcode_TopBox');

// allow additional image file upload
add_filter('upload_mimes', 'cbsonline_allow_additional_image_upload');
function cbsonline_allow_additional_image_upload($mimes)
{
    $mimes['ai'] = 'image/x-illustrator';
    $mimes['ico'] = 'image/vnd.microsoft.icon';

    return $mimes;
}

// force override Archive widget arguments
add_filter('widget_archives_args', 'cbsonline_widget_archives_args');
function cbsonline_widget_archives_args($args)
{
    // yearly
    $args['type'] = 'yearly';
    // maximum number of items : 10 years
    $args['limit'] = 10;

    return $args;
}

// support category based archives
add_filter('getarchives_join', 'cbsonline_category_getarchives_join', 10, 2);
function cbsonline_category_getarchives_join($join, $r)
{
    global $wpdb;
    if (is_category()) {
        $cat = intval(get_query_var('cat'));
        if ($cat > 0) {
            return
              " LEFT JOIN $wpdb->term_relationships as r ON $wpdb->posts.ID = r.object_ID
                LEFT JOIN $wpdb->term_taxonomy as t ON r.term_taxonomy_id = t.term_taxonomy_id
                LEFT JOIN $wpdb->terms as terms ON t.term_id = terms.term_id";
        }
    }
}
add_filter('getarchives_where', 'cbsonline_category_getarchives_where', 10, 2);
function cbsonline_category_getarchives_where($where, $r)
{
    if (is_category()) {
        $cat = intval(get_query_var('cat'));
        if ($cat > 0) {
            return $where." AND t.taxonomy = 'category' AND terms.term_id = $cat";
        }
    }
}
add_filter('year_link', 'cbsonline_category_year_link', 10, 2);
function cbsonline_category_year_link($url, $year)
{
    global $wp_rewrite;
    if (is_category()) {
        $cat = intval(get_query_var('cat'));
        if ($cat > 0) {
            $url .= '?cat='.get_query_var('cat');
        }
    }

    return $url;
}

// support tag cloud for static pages
add_action('init', 'cbsonline_add_tag_to_page');
function cbsonline_add_tag_to_page()
{
    register_taxonomy_for_object_type('post_tag', 'page');
}
add_action('pre_get_posts', 'cbsonline_add_page_to_tag_archive');
function cbsonline_add_page_to_tag_archive($obj)
{
    if (is_tag()) {
        $obj->query_vars['post_type'] = ['post', 'page'];
    }
}
